Changelog
=========

## 1.0.0

### BREAKING CHANGES

- Require Python 3.9+

### Bug fixes

- Fix no such attribute `np.bool8`.


## 0.3.0

- Support reading and writing from objects which support `read()` and
  `write()`.

## 0.2.0

- Improve types of public interface to avoid the need for casting.


## 0.1.0

Initial public release
